<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage FavBlog
 * @since FavBlog 1.0.0
 * @return array An array of default values
 */

function favblog_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$favblog_default_options = array(
		// Color Options
		'header_title_color'			    => '#000',
		'header_tagline_color'			    => '#666',
		'header_txt_logo_extra'			    => 'show-all',
		'search_icon_in_primary_menu_enable'=> true,

		// breadcrumb
		'breadcrumb_enable'				    => (bool) true,
		'breadcrumb_separator'			    => '/',
		
		// layout 
		'site_layout'         			    => 'wide',
		'sidebar_position'         		    => 'right-sidebar',
		'post_sidebar_position' 		    => 'right-sidebar',
		'page_sidebar_position' 		    => 'right-sidebar',
		'menu_sticky'					    => (bool) false,

		// excerpt options
		'long_excerpt_length'               => 25,

		// homepage options
		'enable_frontpage_content' 		=> false,


		// pagination options
		'pagination_enable'         	    => (bool) true,
		'pagination_type'         		    => 'default',

		// footer options
		'copyright_text'           		    => sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'favblog' ), '[the-year]', '[site-link]' ),
		'scroll_top_visible'        	    => (bool) true,

		// reset options
		'reset_options'      			    => (bool) false,
		
		// homepage sections sortable
		'sortable' 						    => 'hero,popular_post,recent_post,most_read',


		// blog/archive options
		'your_latest_posts_title' 		    => esc_html__( 'Blogs', 'favblog' ),
		'hide_date' 					    => (bool) false,
		'hide_category'					    => (bool) false,


		// single post theme options
		'single_post_hide_date' 		    => (bool) false,
		'single_post_hide_author'		    => (bool) false,

		/* Front Page */

		//top bar
		'topbar_section_enable'				=> false,
		'social_menu_enable'				=> false,
		'secondary_menu_enable'				=> false,

		//Hero Section
		'hero_section_enable'				=> false,
		'hero_section_tag_title'			=> esc_html__( 'Popular Tags', 'favblog' ),

		// Popular Post
		'popular_post_title'				=> esc_html__( 'Popular Posts', 'favblog' ),
		'popular_post_sub_title'	     	=> esc_html__( 'Popular', 'favblog' ),
		'popular_post_section_enable'		=> false,

		
		// Recent Post
		'recent_post_title'					=> esc_html__( 'Top Read Reviews', 'favblog' ),
		'recent_post_sub_title'	     		=> esc_html__( 'Recents', 'favblog' ),
		'recent_post_section_enable'		=> false,

		// Top Read
		'most_read_title'					=> esc_html__( 'Top Read Reviews', 'favblog' ),
		'most_read_sub_title'	     		=> esc_html__( 'Most Read', 'favblog' ),
		'most_read_section_enable'			=> false,

	);

	$output = apply_filters( 'favblog_default_theme_options', $favblog_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}